@@ -100,8 +100,8 @@ Progress=""
 #arrDataLen=8640 #(1 value/10sec for 24h), 6*24*60
 ##old             [0]=time            [1]=X,                [2]=Y,                [3]=X Derivation,[4]=Y Derivation
 #             [0]=time            [1]=X,                [2]=Y,                [3]=X+Y Derivation, [4]=Time since last movement over treshhold, [5]=event
-#arrData=[[0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen,        [0]*arrDataLen ,             [0]*arrDataLen] 
-arrDataTemp=[0, 0, 0] #[0]=unused, [1]=X, [2]=Y
+#arrData=[[0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen,        [0]*arrDataLen ,             [0]*arrDataLen]
+arrDataTemp=[0, 0, 0] #[0]=X, [1]=Y, [2]=Z
 arrDataIndex=0
 arrLogFiles=[]
 arrLogFilesIndex=0
@@ -126,7 +126,7 @@ arrFilter=[0, 5, 10, 15, 20, 25, 30, 35, 40, 45, 50, 55, 60, 65, 70, 75, 80, 85,
 
 
 
-#arrDataFiltered=[[0]*MaxArrayDataLen]  
+#arrDataFiltered=[[0]*MaxArrayDataLen]
 FilterShift= 30 #Sync point with movement derivation
 FilterScale=1800
 
