@@ -50,9 +50,14 @@ except:
     MyLib_Imported=False
 
 
+data.app_path=os.path.dirname(__file__)
+if(data.app_path==""): data.app_path="./"
+else: data.app_path=data.app_path+"/"
 
 
-
+#load language file
+import i18n
+_ = i18n.language.gettext
 
 
 
@@ -98,10 +103,13 @@ def main():
     else: data.logfolder=data.defaultlogfolder
 
 
+#
+#    data.app_path=os.path.dirname(__file__)
+#    if(data.app_path==""): data.app_path="./"
+#    else: data.app_path=data.app_path+"/"
+
+
 
-    data.app_path=os.path.dirname(__file__)
-    if(data.app_path==""): data.app_path="./"
-    else: data.app_path=data.app_path+"/"
 
 
     config=LoadConfig()
@@ -116,6 +124,8 @@ def main():
 
 
 
+    print _("Hello World")
+    print _("Line 1\nLine 2")
 
 
     #Load version file
@@ -135,21 +145,23 @@ def main():
 
     #chek if module is available and could get loaded
     if(MyLib_Imported==True): #module is loaded
-        print "Mylib is compiled:", mylib.IsCompiled() #check if module is compiled
+#        print "Mylib is compiled:", mylib.IsCompiled() #check if module is compiled
         if(mylib.IsCompiled()==False): #module is not compiled
-            print "Some functions will work slow as we have to fall back to the unoptimised python code!"
-            cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog " + \
-                     "string:\"SleepAnalyser:\nThe module mylib.so could not get loaded! Please check if there is a never version "+ \
+            txt= "SleepAnalyser:\nThe compiled module mylib.so could not get loaded! Please check if there is a never version "+ \
                      "or inform the maintainer about it! SleepAnalyser will still work, " + \
-                     "but some functions will work slow as we have to fall back to the unoptimised python code!\" uint32:0 string:\"OK\""
+                     "but some functions will work slow as we have to fall back to the unoptimised python code!"
+            print txt
+            cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog " + \
+                     "string:\""+txt+"\" uint32:0 string:\"OK\""
             os.popen(cmd)
     else: #module is available but broken
-        print "Mylib could not be imported. It might be corrupted. You can get SleepAnalyser working by removing the file "+data.app_path+"lib/mylib.so."
-        cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog " + \
-                 "string:\"SleepAnalyser:\nSleepAnalyser could not load the module mylib.so\n" + \
+        txt="SleepAnalyser:\nSleepAnalyser could not load the module mylib.so\n" + \
                  "in "+data.app_path+"lib. It might be corrupted. Please check if there is a never version "+ \
                  "or inform the maintainer about it! You can get SleepAnalyser working by removing the file "+data.app_path+"lib/mylib.so, " + \
-                 "how ever some functions will work slow as we have to fall back to the unoptimised python code!\" uint32:0 string:\"OK\""
+                 "how ever some functions will work slow as we have to fall back to the unoptimised python code!"
+        print txt
+        cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteDialog " + \
+                 "string:\""+txt+"\" uint32:0 string:\"OK\""
         os.popen(cmd)
         exit()
 
@@ -225,9 +237,7 @@ def main():
 def EditUserName():
 #      r=QInputDialog.getText(None,  "Add Note",  "Add a note to this record:\n(leave empty for no note)",  QLineEdit.Normal,  records.Note)
 #        if(r[1]==True): #OK pressed
-    r = QInputDialog.getText(None, "SleepAnalyser", "Please enter your name.\n"+ \
-     "It will be used in the records file, this makes it easier\n" + \
-     "when you want to share your sleep pattern with others.", 0,  data.user)
+    r = QInputDialog.getText(None, "SleepAnalyser", _("Please enter your name.\nIt will be used in the records file, this makes it easier\nwhen you want to share your sleep pattern with others."), 0,  data.user)
 #    if(r != ""):
     if(r[1]==True): #OK pressed
         data.user=unicode(r[0])
@@ -262,8 +272,8 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
 
         if(records.Index==records.MaxArrayDataLen-1):
             print "Stopped, array is full"
-            data.Status="Stopped, array is full!"
-            QtGui.QMessageBox.warning(RecordWindow, 'Memory is full!', "You reached the end of the recording capacity!\nThe recording stops now.", QtGui.QMessageBox.Ok)
+            data.Status=_("Stopped, array is full!")
+            QtGui.QMessageBox.warning(RecordWindow, _('Memory is full!'), _("You reached the end of the recording capacity!\nThe recording stops now."), QtGui.QMessageBox.Ok)
 #            RecordWindow.StopMeasurement()
             StopMeasurement() #stop but keep alarm active!
 
@@ -281,7 +291,7 @@ def MeasurementTimerLoop(): #(interval: sampling*sample_smoothing*value_smoothin
 #        print "Alarm is active"
         if(data.StopAfterAlarm==True):
 #            print "Stop measurement, alarm is active"
-            data.Status="Alarm got activated, stopped recording"
+            data.Status=_("Alarm got activated, stopped recording")
             StopMeasurement() #stop but keep alarm active!
 
 
@@ -293,8 +303,8 @@ def InitMeasurement():
     global app
 
     data.sample_index=0
-    if(data.QuickMode==False): data.Status="Recording..."
-    else: data.Status="Recording in Test Mode..."
+    if(data.QuickMode==False): data.Status=_("Recording...")
+    else: data.Status=_("Recording in Test Mode...")
 
     records.User=data.user
     records.SWversion=data.version
@@ -302,7 +312,7 @@ def InitMeasurement():
     records.Sample_smoothing=data.Sample_smoothing
     records.Value_smoothing=data.Value_smoothing
     records.Trigger=data.Trigger #save Trigger level on start
-    records.statusID="OK"
+    records.statusID=_("OK")
 
     if(data.debug==1): PrintRecordData()
 
@@ -381,7 +391,9 @@ def InitMeasurement():
                     if(data.PreviousProfile=="general"): #was general, change to silent
                         cmd="dbus-send --type=method_call --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.set_profile string:\"silent\" | echo \"\""
                         os.popen(cmd)
-                        cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\"Silent Profile activated\""
+                        txt=_("Silent Profile activated")
+                        print txt
+                        cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\""+txt+"\""
                         os.popen(cmd)
                 except:
                     pass
@@ -429,7 +441,8 @@ def StopMeasurement():
                     if(data.PreviousProfile=="general"): #was general (before start measurement), so restore to general
                         cmd="dbus-send --type=method_call --dest=com.nokia.profiled /com/nokia/profiled com.nokia.profiled.set_profile string:\"general\" | echo \"\""
                         os.popen(cmd)  #set profile
-                        cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\"General Profile activated\""
+                        txt=_("General Profile activated")
+                        cmd="dbus-send --type=method_call --dest=org.freedesktop.Notifications /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint string:\""+txt+"\""
                         os.popen(cmd)  #notification
                 except:
                     pass
@@ -535,7 +548,18 @@ class frmStartWindow(QMainWindow):
 #            self.ui.bConfig.setIcon(QIcon(data.app_path+"img/"+"configure.png"))
 
 
-
+        #set texts
+#        StartWindow.setWindowTitle("SleepAnalyser")
+        self.ui.bLog.setText(_("View records"))
+        self.ui.bCollecting.setText(_("Start recording only"))
+        self.ui.bSetAlarm.setText(_("Set alarm and\n"
+                                                "start recording"))
+        self.ui.lblNote.setText(_("Development version, might be unstable!"))
+        self.ui.menuMenu.setTitle(_("Menu"))
+        self.ui.actionAbout.setText(_("About"))
+        self.ui.actionSettings.setText(_("Settings"))
+        self.ui.actionHelp.setText(_("Help"))
+        self.ui.actionTest_recording.setText(_("Test recording"))
 
 
 
